# Changelog

## 1.33.0 (2026-03-17)

Full Changelog: [v1.32.2...v1.33.0](https://github.com/Avido-AI/avido-py/compare/v1.32.2...v1.33.0)

### Features

* **api:** api update ([9745ef9](https://github.com/Avido-AI/avido-py/commit/9745ef9810ab63b53a6cab5be47dac2804e1f108))


### Chores

* **internal:** tweak CI branches ([4e4f495](https://github.com/Avido-AI/avido-py/commit/4e4f495ee35d260c3abda8389e0193e5b14bf43c))

## 1.32.2 (2026-03-17)

Full Changelog: [v1.32.1...v1.32.2](https://github.com/Avido-AI/avido-py/compare/v1.32.1...v1.32.2)

### Bug Fixes

* **deps:** bump minimum typing-extensions version ([b81fb92](https://github.com/Avido-AI/avido-py/commit/b81fb92bc8af7b01af519fd806e6a9b7825c124e))

## 1.32.1 (2026-03-17)

Full Changelog: [v1.32.0...v1.32.1](https://github.com/Avido-AI/avido-py/compare/v1.32.0...v1.32.1)

### Bug Fixes

* **pydantic:** do not pass `by_alias` unless set ([50658cc](https://github.com/Avido-AI/avido-py/commit/50658cc47293bcdbe787bb4dde1e768cd2b292da))

## 1.32.0 (2026-03-17)

Full Changelog: [v1.31.0...v1.32.0](https://github.com/Avido-AI/avido-py/compare/v1.31.0...v1.32.0)

### Features

* **api:** api update ([f018305](https://github.com/Avido-AI/avido-py/commit/f018305dac1f473a3caf765f008f6212114352a3))

## 1.31.0 (2026-03-13)

Full Changelog: [v1.30.0...v1.31.0](https://github.com/Avido-AI/avido-py/compare/v1.30.0...v1.31.0)

### Features

* **api:** api update ([f0cd47c](https://github.com/Avido-AI/avido-py/commit/f0cd47cb1e4e99a2709f6f9b5689c0c4210ce47b))

## 1.30.0 (2026-03-12)

Full Changelog: [v1.29.0...v1.30.0](https://github.com/Avido-AI/avido-py/compare/v1.29.0...v1.30.0)

### Features

* **api:** api update ([52b4d74](https://github.com/Avido-AI/avido-py/commit/52b4d74610022c55bfc672a25d197f826c57a53f))

## 1.29.0 (2026-03-11)

Full Changelog: [v1.28.0...v1.29.0](https://github.com/Avido-AI/avido-py/compare/v1.28.0...v1.29.0)

### Features

* **api:** api update ([700fc21](https://github.com/Avido-AI/avido-py/commit/700fc21f127685707187f7ad2db764eff6c54f18))

## 1.28.0 (2026-03-11)

Full Changelog: [v1.27.0...v1.28.0](https://github.com/Avido-AI/avido-py/compare/v1.27.0...v1.28.0)

### Features

* **api:** api update ([b7d3f88](https://github.com/Avido-AI/avido-py/commit/b7d3f884e9730de3196624446a9382ae5169db2d))

## 1.27.0 (2026-03-09)

Full Changelog: [v1.26.3...v1.27.0](https://github.com/Avido-AI/avido-py/compare/v1.26.3...v1.27.0)

### Features

* **api:** manual updates ([89a2dce](https://github.com/Avido-AI/avido-py/commit/89a2dcee974002276e056b5a387d721e05f52981))
* **api:** manual updates ([8ba1196](https://github.com/Avido-AI/avido-py/commit/8ba119619718d7514e8a992719646261dc5c2dff))

## 1.26.3 (2026-03-07)

Full Changelog: [v1.26.2...v1.26.3](https://github.com/Avido-AI/avido-py/compare/v1.26.2...v1.26.3)

### Chores

* **ci:** skip uploading artifacts on stainless-internal branches ([15c109c](https://github.com/Avido-AI/avido-py/commit/15c109c9f354a7dc4a0e6737eed4929ccaad0cf8))

## 1.26.2 (2026-03-04)

Full Changelog: [v1.26.1...v1.26.2](https://github.com/Avido-AI/avido-py/compare/v1.26.1...v1.26.2)

### Chores

* update SDK settings ([8948c22](https://github.com/Avido-AI/avido-py/commit/8948c2232631c0d3c4ac797c93ae3a6c7530e1a8))

## 1.26.1 (2026-03-04)

Full Changelog: [v1.26.0...v1.26.1](https://github.com/Avido-AI/avido-py/compare/v1.26.0...v1.26.1)

### Chores

* update SDK settings ([e40f16d](https://github.com/Avido-AI/avido-py/commit/e40f16d00f07af46fe2ab51b9c5a532e1e6cba12))
* update SDK settings ([ebc8724](https://github.com/Avido-AI/avido-py/commit/ebc872423daca2b2a83708fabf418a1433f222f7))

## 1.26.0 (2026-03-04)

Full Changelog: [v1.25.0...v1.26.0](https://github.com/Avido-AI/avido-py/compare/v1.25.0...v1.26.0)

### Features

* **api:** api update ([33e95ec](https://github.com/Avido-AI/avido-py/commit/33e95ec934324c3c24712f21568001b705aab4b0))


### Chores

* **internal:** refactor authentication internals ([f3bc05d](https://github.com/Avido-AI/avido-py/commit/f3bc05d2db6271bb8656018d6814b0850e6a7627))

## 1.25.0 (2026-03-03)

Full Changelog: [v1.24.0...v1.25.0](https://github.com/Avido-AI/avido-py/compare/v1.24.0...v1.25.0)

### Features

* **api:** api update ([aa8d117](https://github.com/Avido-AI/avido-py/commit/aa8d1174b6969e86aadb988b712de5d26660d1c9))


### Chores

* update SDK settings ([d6121fa](https://github.com/Avido-AI/avido-py/commit/d6121fa88e91cec33662de91d7721fa9b560c827))

## 1.24.0 (2026-02-28)

Full Changelog: [v1.23.0...v1.24.0](https://github.com/Avido-AI/avido-py/compare/v1.23.0...v1.24.0)

### Features

* **api:** api update ([a89f3b3](https://github.com/Avido-AI/avido-py/commit/a89f3b3a1be27b3fe640682471e309b16ce95a72))
* **api:** manual updates ([5fefd58](https://github.com/Avido-AI/avido-py/commit/5fefd58d4c601ae5c59adec51c8d631b776d3140))
* **api:** manual updates ([4ca7fd3](https://github.com/Avido-AI/avido-py/commit/4ca7fd304c39eeb444d8a7e8f770e683d5df5de2))
* **api:** manual updates ([71a31cf](https://github.com/Avido-AI/avido-py/commit/71a31cf1bddb61b3d5223617b7a231a930914a5b))
* **api:** reduce endpoints ([f9c0b05](https://github.com/Avido-AI/avido-py/commit/f9c0b050d58888689559be17ccb8c69262fcdd16))


### Chores

* configure new SDK language ([1c25aee](https://github.com/Avido-AI/avido-py/commit/1c25aeeb87277501a03b150abdb5a27590a25c7a))

## 1.23.0 (2026-02-27)

Full Changelog: [v1.22.0...v1.23.0](https://github.com/Avido-AI/avido-py/compare/v1.22.0...v1.23.0)

### Features

* **api:** manual updates ([152be20](https://github.com/Avido-AI/avido-py/commit/152be202bf3133d5aab858a00901c8905f412d02))
* **api:** manual updates ([92889b0](https://github.com/Avido-AI/avido-py/commit/92889b0658c2961f820ff019a1c0d32cec31a78d))
* **api:** manual updates ([da0fd8b](https://github.com/Avido-AI/avido-py/commit/da0fd8bedfe26bf2f39db471c2558778161c9f03))
* **api:** manual updates ([3ffb839](https://github.com/Avido-AI/avido-py/commit/3ffb8396b92002e3f06d7efef06ba4fe36374ff8))
* **api:** manual updates ([47010ad](https://github.com/Avido-AI/avido-py/commit/47010add43ad20e2fa824ab3f5ff91c65c82b611))


### Chores

* **ci:** bump uv version ([c67c270](https://github.com/Avido-AI/avido-py/commit/c67c2702ccdd1acda9500734206e307b4566dd41))
* remove custom code ([7bc18e0](https://github.com/Avido-AI/avido-py/commit/7bc18e087fffb701009240f1479d146defedb160))

## 1.22.0 (2026-02-26)

Full Changelog: [v1.21.0...v1.22.0](https://github.com/Avido-AI/avido-py/compare/v1.21.0...v1.22.0)

### Features

* **api:** api update ([232bfae](https://github.com/Avido-AI/avido-py/commit/232bfae6087aee3d44f960819e6da672b8ac886f))
* **api:** api update ([3137254](https://github.com/Avido-AI/avido-py/commit/313725427137b2664ba03fb5233b666a76e835a7))
* **api:** api update ([dae9347](https://github.com/Avido-AI/avido-py/commit/dae93473d1e10836c55a3a34582ec21aeeac6428))
* **api:** api update ([060681e](https://github.com/Avido-AI/avido-py/commit/060681e134bf41771b8e6cf12f1d236d42053994))
* **api:** api update ([58c0c9f](https://github.com/Avido-AI/avido-py/commit/58c0c9f17e2f5726b3aa3770db861454750b14cd))
* **api:** api update ([96ddef6](https://github.com/Avido-AI/avido-py/commit/96ddef6872817a1cfe8fb271e943564b57af57a3))
* **api:** api update ([19614ac](https://github.com/Avido-AI/avido-py/commit/19614ac89c0a31a9e6b4854c5a9be2c3b28c05cc))
* **api:** manual updates ([d55d733](https://github.com/Avido-AI/avido-py/commit/d55d7339b806b3a4188919b4c0c6ba731c830d32))


### Chores

* configure new SDK language ([0b1251d](https://github.com/Avido-AI/avido-py/commit/0b1251dd5a5ee846f576b9e497d91b17549a8041))
* **internal:** add request options to SSE classes ([0af7f67](https://github.com/Avido-AI/avido-py/commit/0af7f6789e11051a8b2be696fef70a06326675ba))
* **internal:** make `test_proxy_environment_variables` more resilient ([55efd46](https://github.com/Avido-AI/avido-py/commit/55efd46224d4905532d062af7da87c32830fb50e))
* **internal:** make `test_proxy_environment_variables` more resilient to env ([8e8e0b4](https://github.com/Avido-AI/avido-py/commit/8e8e0b442a33c112f508e44794cbeca4b590e7e7))

## 1.21.0 (2026-02-22)

Full Changelog: [v1.20.0...v1.21.0](https://github.com/Avido-AI/avido-py/compare/v1.20.0...v1.21.0)

### Features

* **api:** api update ([d56b26e](https://github.com/Avido-AI/avido-py/commit/d56b26e08c4224a6aa23167a29c5c4b73384148d))

## 1.20.0 (2026-02-20)

Full Changelog: [v1.19.0...v1.20.0](https://github.com/Avido-AI/avido-py/compare/v1.19.0...v1.20.0)

### Features

* **api:** api update ([514898d](https://github.com/Avido-AI/avido-py/commit/514898d7a50947d925c54bf6bd0d97cf7c97ceae))


### Chores

* **internal:** remove mock server code ([df7a767](https://github.com/Avido-AI/avido-py/commit/df7a7676302e45d3bfad937207d6626f8aaebe84))
* update mock server docs ([f74f0ee](https://github.com/Avido-AI/avido-py/commit/f74f0eeac899b93d7b7bb2e7903c4c87f73b8943))

## 1.19.0 (2026-02-16)

Full Changelog: [v1.18.1...v1.19.0](https://github.com/Avido-AI/avido-py/compare/v1.18.1...v1.19.0)

### Features

* **api:** api update ([a31082c](https://github.com/Avido-AI/avido-py/commit/a31082cfbb46b49124aba869f82cee79947305bd))
* **api:** api update ([136b9eb](https://github.com/Avido-AI/avido-py/commit/136b9eb3e1701cdf6f4c2c2dcc835ba0614c2a91))


### Chores

* format all `api.md` files ([82c0770](https://github.com/Avido-AI/avido-py/commit/82c07704f0d02314be8d5b88aca946d67f5193a8))
* **internal:** fix lint error on Python 3.14 ([e94e8b6](https://github.com/Avido-AI/avido-py/commit/e94e8b66f6f32d2970a9871dc1c97cae0f56e9ef))

## 1.18.1 (2026-02-10)

Full Changelog: [v1.18.0...v1.18.1](https://github.com/Avido-AI/avido-py/compare/v1.18.0...v1.18.1)

### Chores

* **internal:** bump dependencies ([4163a4f](https://github.com/Avido-AI/avido-py/commit/4163a4fde20d60246da9f2d599718ffb4eb754f6))

## 1.18.0 (2026-02-06)

Full Changelog: [v1.17.0...v1.18.0](https://github.com/Avido-AI/avido-py/compare/v1.17.0...v1.18.0)

### Features

* **api:** api update ([613b1a6](https://github.com/Avido-AI/avido-py/commit/613b1a65ded12342fa651231b69cc591300bfa25))

## 1.17.0 (2026-01-30)

Full Changelog: [v1.16.1...v1.17.0](https://github.com/Avido-AI/avido-py/compare/v1.16.1...v1.17.0)

### Features

* **client:** add custom JSON encoder for extended type support ([c1db7d0](https://github.com/Avido-AI/avido-py/commit/c1db7d0407916e9c8c75d5845a663c555da6420c))

## 1.16.1 (2026-01-24)

Full Changelog: [v1.16.0...v1.16.1](https://github.com/Avido-AI/avido-py/compare/v1.16.0...v1.16.1)

### Chores

* **ci:** upgrade `actions/github-script` ([da68abf](https://github.com/Avido-AI/avido-py/commit/da68abf1875cbfd4429218d17235bef61ce1faf5))

## 1.16.0 (2026-01-20)

Full Changelog: [v1.15.0...v1.16.0](https://github.com/Avido-AI/avido-py/compare/v1.15.0...v1.16.0)

### Features

* **api:** api update ([143c2d3](https://github.com/Avido-AI/avido-py/commit/143c2d3016644383d3c79f0873a9d6d53d66098e))

## 1.15.0 (2026-01-17)

Full Changelog: [v1.14.0...v1.15.0](https://github.com/Avido-AI/avido-py/compare/v1.14.0...v1.15.0)

### Features

* **api:** api update ([aa45eee](https://github.com/Avido-AI/avido-py/commit/aa45eee84138c74e736be09101249229c730b9fb))
* **api:** api update ([87a05f9](https://github.com/Avido-AI/avido-py/commit/87a05f9ed1f0b4a4e7231e9f8f02a222e4a86878))
* **api:** api update ([b26d67c](https://github.com/Avido-AI/avido-py/commit/b26d67ca9adb6deaf3c4eabd9eb95c3548096f16))
* **api:** api update ([614f4ff](https://github.com/Avido-AI/avido-py/commit/614f4ffd8afe9511b51261605831322c3174710c))
* **api:** api update ([a93950d](https://github.com/Avido-AI/avido-py/commit/a93950d9ab3c1cf6f7c91038c8b37e8a2919e2bb))
* **api:** api update ([3edad3d](https://github.com/Avido-AI/avido-py/commit/3edad3dfdfa485bdebda6e12e2a8782328cc367a))
* **client:** add support for binary request streaming ([50f22ee](https://github.com/Avido-AI/avido-py/commit/50f22ee3bd68d6ef3bd2e9ebad3557f2acf43fe0))


### Chores

* **internal:** update `actions/checkout` version ([97efc53](https://github.com/Avido-AI/avido-py/commit/97efc530a1e57d2f555ceca6ee7349a2b94a7297))

## 1.14.0 (2026-01-08)

Full Changelog: [v1.13.8...v1.14.0](https://github.com/Avido-AI/avido-py/compare/v1.13.8...v1.14.0)

### Features

* **api:** api update ([41ac0bc](https://github.com/Avido-AI/avido-py/commit/41ac0bc047682a87163145b420c9def8f8f86035))
* **api:** api update ([44ac9a3](https://github.com/Avido-AI/avido-py/commit/44ac9a32ff102a048ff57dd6dd6e500db8977546))
* **api:** api update ([559ab2d](https://github.com/Avido-AI/avido-py/commit/559ab2d7840d8b4efdf1400dbd21bcc9a306dd48))
* **api:** update api ([b37fd24](https://github.com/Avido-AI/avido-py/commit/b37fd249fa0f2387a417fa9b591983058c75af99))


### Bug Fixes

* **types:** allow pyright to infer TypedDict types within SequenceNotStr ([c36933b](https://github.com/Avido-AI/avido-py/commit/c36933beedf4dbd157365c8e80032a91a3858344))
* use async_to_httpx_files in patch method ([a574617](https://github.com/Avido-AI/avido-py/commit/a57461711059d648eca9eff7e2636fa14abe77ef))


### Chores

* add missing docstrings ([38f524a](https://github.com/Avido-AI/avido-py/commit/38f524aee2cfa6485eecc264c2ddf3b06fb070d6))
* Auto updates from Stainless ([d4fced5](https://github.com/Avido-AI/avido-py/commit/d4fced5788f86a5599a7f2c373ad52a66ae0af28))
* Auto updates from Stainless ([1d1ce13](https://github.com/Avido-AI/avido-py/commit/1d1ce1357e67653b4e06a8b0cd2bb46e44c4169f))
* Auto updates from Stainless ([075a4f2](https://github.com/Avido-AI/avido-py/commit/075a4f2cce98f0a73f35db4b126393aa1abcda19))
* Auto updates from Stainless ([538ccf6](https://github.com/Avido-AI/avido-py/commit/538ccf6e8aa3755233948fd61aafee3997c46de7))
* Auto updates from Stainless ([cc0eff4](https://github.com/Avido-AI/avido-py/commit/cc0eff4c1e75291a5d2cbf8b78846049c32b1b5d))
* Auto updates from Stainless ([dfa0e03](https://github.com/Avido-AI/avido-py/commit/dfa0e03a45f0038a4661d9ae6a8fa8da7f9dd1b1))
* Auto updates from Stainless ([22c5074](https://github.com/Avido-AI/avido-py/commit/22c5074ea972bea0804138d2878e2cac60e3ac2d))
* **internal:** add `--fix` argument to lint script ([8042955](https://github.com/Avido-AI/avido-py/commit/80429552c6581ae128089286f5407b3fcd1a014b))
* **internal:** add missing files argument to base client ([a3aee57](https://github.com/Avido-AI/avido-py/commit/a3aee571dc2c0f3a29ca351095ad8acd7b0aa9fa))
* speedup initial import ([25772f8](https://github.com/Avido-AI/avido-py/commit/25772f82e18d2dceba4001e99cb805c0e560a412))


### Documentation

* add more examples ([dedff19](https://github.com/Avido-AI/avido-py/commit/dedff19c7177208dd50dc082b786a04428eb4965))

## 1.13.8 (2025-12-07)

Full Changelog: [v1.13.7...v1.13.8](https://github.com/Avido-AI/avido-py/compare/v1.13.7...v1.13.8)

### Bug Fixes

* ensure streams are always closed ([7c159c5](https://github.com/Avido-AI/avido-py/commit/7c159c565ac34a468de1b72453b44d5e828b2667))


### Chores

* Auto updates from Stainless ([7cec218](https://github.com/Avido-AI/avido-py/commit/7cec2182b5f23d37999bdc5498d10ccd7a4e0314))
* Auto updates from Stainless ([12c620a](https://github.com/Avido-AI/avido-py/commit/12c620a0f1bc4e469a3c30631b453143268ec603))
* Auto updates from Stainless ([d89c8f3](https://github.com/Avido-AI/avido-py/commit/d89c8f3ba560e890ac2c2914fa35a300bebba8f7))
* Auto updates from Stainless ([5f09404](https://github.com/Avido-AI/avido-py/commit/5f09404129795b5dc91d7c87c9a597f743765d9a))
* Auto updates from Stainless ([47fc3d9](https://github.com/Avido-AI/avido-py/commit/47fc3d98202813c2e671c44376bce12c1b1b7ae1))
* Auto updates from Stainless ([20a3404](https://github.com/Avido-AI/avido-py/commit/20a3404e6b8f4524e9a0f8143058680f63c01b64))
* Auto updates from Stainless ([05d7833](https://github.com/Avido-AI/avido-py/commit/05d7833383c3ccc8445a07a64a7af6a8d976835f))
* Auto updates from Stainless ([bcc1d1d](https://github.com/Avido-AI/avido-py/commit/bcc1d1dee1a03b0840e9acab62537a36c0177f6c))
* Auto updates from Stainless ([15ab4d2](https://github.com/Avido-AI/avido-py/commit/15ab4d2a6ded6f97b786d24d973dafc748a38248))
* Auto updates from Stainless ([043ebb3](https://github.com/Avido-AI/avido-py/commit/043ebb37384a6d27dbe3cba273ac6ccd4c4fca91))
* **deps:** mypy 1.18.1 has a regression, pin to 1.17 ([166f127](https://github.com/Avido-AI/avido-py/commit/166f127f6c755411da74c47b04034377b2de31c2))
* **docs:** use environment variables for authentication in code snippets ([4187404](https://github.com/Avido-AI/avido-py/commit/4187404e78a3b55d90bdcc743ac054efcb7ae56a))
* update lockfile ([d0df6b1](https://github.com/Avido-AI/avido-py/commit/d0df6b12a54258bc5c7a4a968984fef98dca7734))

## 1.13.7 (2025-11-25)

Full Changelog: [v1.13.6...v1.13.7](https://github.com/Avido-AI/avido-py/compare/v1.13.6...v1.13.7)

### Chores

* add Python 3.14 classifier and testing ([dbc60d9](https://github.com/Avido-AI/avido-py/commit/dbc60d9b750183172f13dce46a37a60f9c380b42))
* Auto updates from Stainless ([5103887](https://github.com/Avido-AI/avido-py/commit/510388782bf673f669be0693ec9654b4c85471bc))
* Auto updates from Stainless ([be5f1a2](https://github.com/Avido-AI/avido-py/commit/be5f1a2258c11483403ba06698d4535f14f28bab))
* Auto updates from Stainless ([4aa75b4](https://github.com/Avido-AI/avido-py/commit/4aa75b4658c18b6fb612eb34f4469eea66de9e3f))
* Auto updates from Stainless ([6d1330a](https://github.com/Avido-AI/avido-py/commit/6d1330af0150d7a81d6deba4f910bb4010b7df03))

## 1.13.6 (2025-11-17)

Full Changelog: [v1.13.5...v1.13.6](https://github.com/Avido-AI/avido-py/compare/v1.13.5...v1.13.6)

### Bug Fixes

* compat with Python 3.14 ([1056048](https://github.com/Avido-AI/avido-py/commit/105604828e2a646c15da15bfbda2501bd2c89c66))
* **compat:** update signatures of `model_dump` and `model_dump_json` for Pydantic v1 ([eb1e593](https://github.com/Avido-AI/avido-py/commit/eb1e59372700ea19e13b8ab55d6320c267049140))


### Chores

* Auto updates from Stainless ([5a59a8e](https://github.com/Avido-AI/avido-py/commit/5a59a8e86f8ed6aec09c834e698fa3d76a1c4dc9))
* Auto updates from Stainless ([027b842](https://github.com/Avido-AI/avido-py/commit/027b842cc378e3139f601ccb510ecf5f1c59bf8b))
* Auto updates from Stainless ([a0f1292](https://github.com/Avido-AI/avido-py/commit/a0f1292358c47a2bd9068f7188538e89b347d57a))
* Auto updates from Stainless ([5af274a](https://github.com/Avido-AI/avido-py/commit/5af274abe6d4272ca611c74cf0d9c5b1d0b1835b))
* Auto updates from Stainless ([321b356](https://github.com/Avido-AI/avido-py/commit/321b356ea45a092a70abd1ecc81b6667cd861a57))
* Auto updates from Stainless ([ca98951](https://github.com/Avido-AI/avido-py/commit/ca989514928be48eb6f8031afbe3665dc93f7c62))
* Auto updates from Stainless ([f79be59](https://github.com/Avido-AI/avido-py/commit/f79be59aa95342f26d48c1758dc8fe99e610ccb6))
* Auto updates from Stainless ([db20ae2](https://github.com/Avido-AI/avido-py/commit/db20ae211a6684da124d2fc5dffa7f9e4a063b4d))
* Auto updates from Stainless ([1220901](https://github.com/Avido-AI/avido-py/commit/1220901bc16257d66b41fb63e2f9a43ea2271de6))
* Auto updates from Stainless ([27660f7](https://github.com/Avido-AI/avido-py/commit/27660f7e68e43b5b542d56788e785557926bad7d))
* Auto updates from Stainless ([bece8db](https://github.com/Avido-AI/avido-py/commit/bece8dbeed53fd91610462908d9c6a7de25336eb))
* **internal:** grammar fix (it's -&gt; its) ([eb42d49](https://github.com/Avido-AI/avido-py/commit/eb42d4919e15a1bdc62674ee09abbe94280957a7))
* **package:** drop Python 3.8 support ([2a72525](https://github.com/Avido-AI/avido-py/commit/2a72525f0f72ab95258407d8b87ed5b2e4064fda))

## 1.13.5 (2025-10-31)

Full Changelog: [v1.13.4...v1.13.5](https://github.com/Avido-AI/avido-py/compare/v1.13.4...v1.13.5)

### Bug Fixes

* **client:** close streams without requiring full consumption ([2f64408](https://github.com/Avido-AI/avido-py/commit/2f644086d1ad65ef322bc9acf3a995d384a0a377))


### Chores

* Auto updates from Stainless ([a05e320](https://github.com/Avido-AI/avido-py/commit/a05e320be447fb4d09800001f82da6bd0df22aaf))
* Auto updates from Stainless ([37e1aa7](https://github.com/Avido-AI/avido-py/commit/37e1aa79aa6006863686c8461a952d77b5f05223))
* **internal/tests:** avoid race condition with implicit client cleanup ([9734520](https://github.com/Avido-AI/avido-py/commit/97345202006ebac30c065cbf06afd196a5fccb2c))

## 1.13.4 (2025-10-27)

Full Changelog: [v1.13.3...v1.13.4](https://github.com/Avido-AI/avido-py/compare/v1.13.3...v1.13.4)

### Chores

* Auto updates from Stainless ([9c9cc3a](https://github.com/Avido-AI/avido-py/commit/9c9cc3a0e9f4528640076c4d7fcbb5f452b606e8))
* Auto updates from Stainless ([afa36d6](https://github.com/Avido-AI/avido-py/commit/afa36d66b0b99fe684045a7498275e374508ebd5))
* Auto updates from Stainless ([cec480a](https://github.com/Avido-AI/avido-py/commit/cec480a251d1f2012cf6562cc7da85e9cab3147a))
* Auto updates from Stainless ([6d30f79](https://github.com/Avido-AI/avido-py/commit/6d30f7937e0c45e1196ce8eadb2f7a3bf0a64b34))

## 1.13.3 (2025-10-20)

Full Changelog: [v1.13.2...v1.13.3](https://github.com/Avido-AI/avido-py/compare/v1.13.2...v1.13.3)

### Chores

* Auto updates from Stainless ([c1addb8](https://github.com/Avido-AI/avido-py/commit/c1addb8f9428798602a6d111b2ffd747a865074e))
* Auto updates from Stainless ([022d1f9](https://github.com/Avido-AI/avido-py/commit/022d1f95839cfd31e4f680065451502397627ad1))
* Auto updates from Stainless ([3b14d07](https://github.com/Avido-AI/avido-py/commit/3b14d0775d1924176d587e9227997e5bbe3c20e4))
* Auto updates from Stainless ([103e2e9](https://github.com/Avido-AI/avido-py/commit/103e2e9c2a046125e32993288b609a686c05078f))
* Auto updates from Stainless ([8cffd82](https://github.com/Avido-AI/avido-py/commit/8cffd82878e5ebfa02cbf8f251eb402934319ecb))
* bump `httpx-aiohttp` version to 0.1.9 ([a54b74d](https://github.com/Avido-AI/avido-py/commit/a54b74d934e3cafe38de9a97e7ccf8f7e916f4d9))
* **internal:** detect missing future annotations with ruff ([5eeb8f9](https://github.com/Avido-AI/avido-py/commit/5eeb8f956d0ed46dece4970be0c81ee701ca209c))

## 1.13.2 (2025-10-08)

Full Changelog: [v1.13.1...v1.13.2](https://github.com/Avido-AI/avido-py/compare/v1.13.1...v1.13.2)

### Chores

* Auto updates from Stainless ([a83001c](https://github.com/Avido-AI/avido-py/commit/a83001c7b6d91a0c2e9f9cb6c7c9e0180e92312a))

## 1.13.1 (2025-10-08)

Full Changelog: [v1.13.0...v1.13.1](https://github.com/Avido-AI/avido-py/compare/v1.13.0...v1.13.1)

### Chores

* Auto updates from Stainless ([4fd4c65](https://github.com/Avido-AI/avido-py/commit/4fd4c650af8e3017d09580d6f73ae6e52b41c86d))

## 1.13.0 (2025-10-08)

Full Changelog: [v1.12.0...v1.13.0](https://github.com/Avido-AI/avido-py/compare/v1.12.0...v1.13.0)

### Features

* clean up environment call outs ([907880a](https://github.com/Avido-AI/avido-py/commit/907880a86f6bcc0dac41c47ed43041a0328bae0b))
* **client:** add support for aiohttp ([342ca11](https://github.com/Avido-AI/avido-py/commit/342ca11ff4f350e78b1e6a45bc1ff46aced74d9d))
* **client:** support file upload requests ([39ca92d](https://github.com/Avido-AI/avido-py/commit/39ca92db4c137e224df6c4c036e48d22888c4716))
* improve future compat with pydantic v3 ([7f6dc9c](https://github.com/Avido-AI/avido-py/commit/7f6dc9c642c03f184c0fd0478653aca95da9f626))
* **types:** replace List[str] with SequenceNotStr in params ([5939433](https://github.com/Avido-AI/avido-py/commit/593943344589865abe9fb7efc086a0f4ee4f9812))


### Bug Fixes

* avoid newer type syntax ([0ae73a1](https://github.com/Avido-AI/avido-py/commit/0ae73a10a8279c97fc0caf939d3ab0dacebaae85))
* **ci:** correct conditional ([f4313fc](https://github.com/Avido-AI/avido-py/commit/f4313fc59d1c5ca65386f5a908b805bdf0b55716))
* **ci:** release-doctor — report correct token name ([f75acb2](https://github.com/Avido-AI/avido-py/commit/f75acb2572c18eb5a4f8735061d3d2cd64f03435))
* **client:** don't send Content-Type header on GET requests ([5e31215](https://github.com/Avido-AI/avido-py/commit/5e31215c41fc437b2629cea8c82a2d3d3544557b))
* **parsing:** correctly handle nested discriminated unions ([d42fb86](https://github.com/Avido-AI/avido-py/commit/d42fb86366ec69e9fe01b6f111f511633df365f4))
* **parsing:** ignore empty metadata ([ea77b7c](https://github.com/Avido-AI/avido-py/commit/ea77b7ccccc71d9276219b5c4b901eb42713f7e9))
* **parsing:** parse extra field types ([5e32506](https://github.com/Avido-AI/avido-py/commit/5e32506c944bc7f6571dc6534285eb06f5074463))
* **tests:** fix: tests which call HTTP endpoints directly with the example parameters ([64946d1](https://github.com/Avido-AI/avido-py/commit/64946d12355ef0ee6deb62aa5971c086c527c964))


### Chores

* Auto updates from Stainless ([e9dc7fe](https://github.com/Avido-AI/avido-py/commit/e9dc7fec40cce8c118b0a40eca7489640bc712b7))
* Auto updates from Stainless ([575a8fc](https://github.com/Avido-AI/avido-py/commit/575a8fc9576fe337b68e7bfe3a924fc601d70fad))
* Auto updates from Stainless ([37b2416](https://github.com/Avido-AI/avido-py/commit/37b241650a9b1444b9a6a71ba5fe64ecf1bee800))
* Auto updates from Stainless ([b2830f7](https://github.com/Avido-AI/avido-py/commit/b2830f76e5f8a99320cc35f8de0f3f046b6e0c65))
* Auto updates from Stainless ([4149b84](https://github.com/Avido-AI/avido-py/commit/4149b8448cbf9c4390d9d3054520cafc19c47d20))
* Auto updates from Stainless ([6f7eb13](https://github.com/Avido-AI/avido-py/commit/6f7eb13e0edd00db810619d0eff4741b05b2e4ce))
* Auto updates from Stainless ([99fd7f9](https://github.com/Avido-AI/avido-py/commit/99fd7f95d08378264ff6444bdcdf19784d1fc6c6))
* **ci:** change upload type ([8247334](https://github.com/Avido-AI/avido-py/commit/8247334f24ce299aa73e5d34dff52ada8daec9c4))
* **ci:** enable for pull requests ([b2a5211](https://github.com/Avido-AI/avido-py/commit/b2a5211fc5e6cf1d68b688225d89c8be91c4a5f4))
* **ci:** only run for pushes and fork pull requests ([5e0bd5b](https://github.com/Avido-AI/avido-py/commit/5e0bd5b7679a8ad3a2086ec2b663f1625f691af3))
* do not install brew dependencies in ./scripts/bootstrap by default ([6a46682](https://github.com/Avido-AI/avido-py/commit/6a466824c1a4c8fd596446ba0b7f7eb956d4b1cd))
* **internal:** add Sequence related utils ([849535f](https://github.com/Avido-AI/avido-py/commit/849535f1946e15ff4cf4f69cad04eb8dcbe2b2e7))
* **internal:** bump pinned h11 dep ([d4c6d5c](https://github.com/Avido-AI/avido-py/commit/d4c6d5c489f21ad89e2595310a428c30d883851a))
* **internal:** change ci workflow machines ([9d72656](https://github.com/Avido-AI/avido-py/commit/9d7265625c13275472ecb46f19a92b4cabcb12fb))
* **internal:** codegen related update ([0ac9f9c](https://github.com/Avido-AI/avido-py/commit/0ac9f9ce085609af0214540153d454e87423bb8f))
* **internal:** fix ruff target version ([92061f8](https://github.com/Avido-AI/avido-py/commit/92061f8978258bd49995ec71b676b56c6bd4eb62))
* **internal:** move mypy configurations to `pyproject.toml` file ([6ba371b](https://github.com/Avido-AI/avido-py/commit/6ba371b5926f210cfe8a593af2d51e66143e451f))
* **internal:** update comment in script ([86f5ccb](https://github.com/Avido-AI/avido-py/commit/86f5ccbfd7a0fbbfd7c88a9071479e1365277e50))
* **internal:** update conftest.py ([d322e7b](https://github.com/Avido-AI/avido-py/commit/d322e7b9da293bec69608eb3339b044ba0daa6c4))
* **internal:** update pydantic dependency ([b21c08f](https://github.com/Avido-AI/avido-py/commit/b21c08f779ce5d13845453b3a36baffc879e622e))
* **internal:** update pyright exclude list ([ab646f5](https://github.com/Avido-AI/avido-py/commit/ab646f56ff78c3820497530d442acb68d6ccf5b9))
* **package:** mark python 3.13 as supported ([e543cbe](https://github.com/Avido-AI/avido-py/commit/e543cbe64c6eb7f31002236808ed0b978e433fa0))
* **project:** add settings file for vscode ([54c3a69](https://github.com/Avido-AI/avido-py/commit/54c3a693136a61fcb716656766a4871822bbe3eb))
* **readme:** fix version rendering on pypi ([2595e8e](https://github.com/Avido-AI/avido-py/commit/2595e8e1f9193f41d8a552de2b79ae418edd673c))
* **readme:** update badges ([2cc73f6](https://github.com/Avido-AI/avido-py/commit/2cc73f6b69098a5084249653e4567836578b13b9))
* **tests:** add tests for httpx client instantiation & proxies ([902b621](https://github.com/Avido-AI/avido-py/commit/902b62171e265f59a0032adf83a5ce63f5eca755))
* **tests:** simplify `get_platform` test ([d18aef9](https://github.com/Avido-AI/avido-py/commit/d18aef9acb6feba8fae1f0e87623b23839ece51b))
* **tests:** skip some failing tests on the latest python versions ([e7929f5](https://github.com/Avido-AI/avido-py/commit/e7929f5ac1ee3aa1fcb7ca5a13df48899dd141d3))
* **types:** change optional parameter type from NotGiven to Omit ([09a91aa](https://github.com/Avido-AI/avido-py/commit/09a91aa95b0d396ec6f019201eac0e09c4210c99))
* update @stainless-api/prism-cli to v5.15.0 ([6c924ef](https://github.com/Avido-AI/avido-py/commit/6c924ef27e03a36ea70c4a7cd803024759dc2283))
* update github action ([0d1cd25](https://github.com/Avido-AI/avido-py/commit/0d1cd2547324c2a21dfdab130fc9c99f3104a729))


### Documentation

* **client:** fix httpx.Timeout documentation reference ([430adc4](https://github.com/Avido-AI/avido-py/commit/430adc4c916ab0586a59955811ab672e73fd2e53))

## 1.12.0 (2025-06-13)

Full Changelog: [v1.11.0...v1.12.0](https://github.com/Avido-AI/avido-py/compare/v1.11.0...v1.12.0)

### Features

* **api:** manual updates ([45feb1c](https://github.com/Avido-AI/avido-py/commit/45feb1c558056f99f0a158fc1a98faa04b2a7d8a))
* **api:** manual updates ([44aa21c](https://github.com/Avido-AI/avido-py/commit/44aa21cf01dc6e88f3e8cae9a5a5951e51bce107))


### Bug Fixes

* **client:** correctly parse binary response | stream ([0c525c6](https://github.com/Avido-AI/avido-py/commit/0c525c603bd44c05c4f5cafb40aba8df78711a07))


### Chores

* Auto updates from Stainless ([839e5e5](https://github.com/Avido-AI/avido-py/commit/839e5e5c70875d5a172e78912b1e9e3efccaf01f))
* Auto updates from Stainless ([95dc496](https://github.com/Avido-AI/avido-py/commit/95dc4969aadf76b39b4ba807267fa0a0df654645))
* **tests:** run tests in parallel ([380753f](https://github.com/Avido-AI/avido-py/commit/380753f36c32ff0bb1ee7b4a43985cfdb14aecc4))

## 1.11.0 (2025-06-06)

Full Changelog: [v1.10.0...v1.11.0](https://github.com/Avido-AI/avido-py/compare/v1.10.0...v1.11.0)

### Features

* **api:** manual updates ([da3e594](https://github.com/Avido-AI/avido-py/commit/da3e594e01c960192b360afc51d2a4c0fe2ac4f0))
* **client:** add follow_redirects request option ([86d75a7](https://github.com/Avido-AI/avido-py/commit/86d75a7e7efe08cdacd012d2bd4e29dd717a0ff4))


### Chores

* **docs:** remove reference to rye shell ([22ca6cf](https://github.com/Avido-AI/avido-py/commit/22ca6cf9b70110be1364a1ed96a4ee38e8fe1a0a))

## 1.10.0 (2025-05-30)

Full Changelog: [v1.9.2...v1.10.0](https://github.com/Avido-AI/avido-py/compare/v1.9.2...v1.10.0)

### Features

* **api:** documents ([628763d](https://github.com/Avido-AI/avido-py/commit/628763d0267061c21a22ce842b3b5a4a8b9312d1))
* **api:** manual updates ([e30c79c](https://github.com/Avido-AI/avido-py/commit/e30c79c69fece35cae2e7b5a6f0859facf834a40))


### Chores

* Auto updates from Stainless ([98dbdaf](https://github.com/Avido-AI/avido-py/commit/98dbdaf9baefb60848e1c92c3df6c1a1daf4a4a1))
* Auto updates from Stainless ([b1440ea](https://github.com/Avido-AI/avido-py/commit/b1440ea82f0e85ef41bb373d8ad623f0e580b395))
* Auto updates from Stainless ([327fcc5](https://github.com/Avido-AI/avido-py/commit/327fcc546484cd5e9d1b7cba0ce9e653ae0d17dd))
* **ci:** fix installation instructions ([c876a19](https://github.com/Avido-AI/avido-py/commit/c876a190c3eaeb694ec14c98ac6231fb61a4820e))
* **docs:** grammar improvements ([365542c](https://github.com/Avido-AI/avido-py/commit/365542c1d57f8566d1520bf1f40f697268ace6b8))

## 1.9.2 (2025-05-15)

Full Changelog: [v1.9.1...v1.9.2](https://github.com/Avido-AI/avido-py/compare/v1.9.1...v1.9.2)

### Chores

* Auto updates from Stainless ([933d440](https://github.com/Avido-AI/avido-py/commit/933d4403a48150e04018ea010b30ee2515e02805))

## 1.9.1 (2025-05-15)

Full Changelog: [v1.9.0...v1.9.1](https://github.com/Avido-AI/avido-py/compare/v1.9.0...v1.9.1)

### Bug Fixes

* **package:** support direct resource imports ([f462d31](https://github.com/Avido-AI/avido-py/commit/f462d31182a0691d7181522824b0973e94e3a659))
* **perf:** optimize some hot paths ([edbe209](https://github.com/Avido-AI/avido-py/commit/edbe2097427843c905c7217efe507f194ef05215))
* **perf:** skip traversing types for NotGiven values ([c896aee](https://github.com/Avido-AI/avido-py/commit/c896aeeee6cfe27c4eb6b42b7d02c2951b2cfacc))
* **pydantic v1:** more robust ModelField.annotation check ([1f5f64d](https://github.com/Avido-AI/avido-py/commit/1f5f64d4f94ce2594861103a72d31c7d20998f95))


### Chores

* Auto updates from Stainless ([89c0c6c](https://github.com/Avido-AI/avido-py/commit/89c0c6c4cd7cbf8ffc0d55808aaad59cb57d4125))
* Auto updates from Stainless ([a862c7f](https://github.com/Avido-AI/avido-py/commit/a862c7f35c5afef1ee099632b02e1e5e81fae00e))
* Auto updates from Stainless ([251078a](https://github.com/Avido-AI/avido-py/commit/251078ae8f2e2ea9a1e40237c1840f118b339a42))
* Auto updates from Stainless ([7fdae91](https://github.com/Avido-AI/avido-py/commit/7fdae91ade4fb72e300cff5b197501006df7e0e6))
* broadly detect json family of content-type headers ([ce65adf](https://github.com/Avido-AI/avido-py/commit/ce65adfc1f842bca52cae8d51b4ce821088b53f2))
* **ci:** add timeout thresholds for CI jobs ([e374f9a](https://github.com/Avido-AI/avido-py/commit/e374f9a651c3dae72327fc80bdb3596a0d2285cc))
* **ci:** only use depot for staging repos ([1bdca53](https://github.com/Avido-AI/avido-py/commit/1bdca53655dccd2f311fd3b6318fac0a7ab3e986))
* **ci:** upload sdks to package manager ([bdc8ae7](https://github.com/Avido-AI/avido-py/commit/bdc8ae7ae2e7be0535e75c8c7f7cf997f86d61ec))
* **client:** minor internal fixes ([e40a715](https://github.com/Avido-AI/avido-py/commit/e40a715514b7275af50f9f9f2d0670c005c7ff29))
* **internal:** avoid errors for isinstance checks on proxies ([1a43c56](https://github.com/Avido-AI/avido-py/commit/1a43c56a48caf932e7d1222d5aee3ef430ac088a))
* **internal:** avoid lint errors in pagination expressions ([724d36d](https://github.com/Avido-AI/avido-py/commit/724d36dfa32c1f7632e03f5963f2b0a0a2f505fe))
* **internal:** base client updates ([0821b79](https://github.com/Avido-AI/avido-py/commit/0821b7957b9f70204faadb64dd0a4d574c543387))
* **internal:** bump pyright version ([b4b7cf5](https://github.com/Avido-AI/avido-py/commit/b4b7cf59cd26f15b741f7351365b03676c5b5849))
* **internal:** codegen related update ([ebfaa43](https://github.com/Avido-AI/avido-py/commit/ebfaa43424112d329a51a5f649e676a82f5c0d91))
* **internal:** codegen related update ([378c99e](https://github.com/Avido-AI/avido-py/commit/378c99e1b952bb88006b54c4d28c06d8920472fe))
* **internal:** expand CI branch coverage ([34c21e3](https://github.com/Avido-AI/avido-py/commit/34c21e335172197dbc1b051aa46865d473070ea3))
* **internal:** fix list file params ([ff03e6e](https://github.com/Avido-AI/avido-py/commit/ff03e6e90ad348e939d762da2cf901082872cc11))
* **internal:** import reformatting ([e717e90](https://github.com/Avido-AI/avido-py/commit/e717e90bff5b53535e7d211761186219b4215372))
* **internal:** minor formatting changes ([b750060](https://github.com/Avido-AI/avido-py/commit/b75006025f6ff99b5424f96ec70c45693b667e6f))
* **internal:** reduce CI branch coverage ([368e4ad](https://github.com/Avido-AI/avido-py/commit/368e4adcae0a8eefe4baa6ab7858c8f744643961))
* **internal:** refactor retries to not use recursion ([150f5ac](https://github.com/Avido-AI/avido-py/commit/150f5acaea474cce30eea8255eccf5b4418ff772))
* **internal:** update models test ([98ba007](https://github.com/Avido-AI/avido-py/commit/98ba0076e88158c7fd73d3c38558067f915667a6))
* **internal:** update pyright settings ([7e0bc76](https://github.com/Avido-AI/avido-py/commit/7e0bc7630179236f3bfa17838889f299f4e6b7db))

## 1.9.0 (2025-04-09)

Full Changelog: [v1.8.0...v1.9.0](https://github.com/Avido-AI/avido-py/compare/v1.8.0...v1.9.0)

### Features

* **api:** authentication ([#101](https://github.com/Avido-AI/avido-py/issues/101)) ([082b9ea](https://github.com/Avido-AI/avido-py/commit/082b9ea048a3a650fbed881f63622fd042cb2e3d))
* **api:** manual updates ([#90](https://github.com/Avido-AI/avido-py/issues/90)) ([dc437e6](https://github.com/Avido-AI/avido-py/commit/dc437e6831340b64192df83de0d8845ed99ab909))
* **api:** manual updates ([#91](https://github.com/Avido-AI/avido-py/issues/91)) ([134c10b](https://github.com/Avido-AI/avido-py/commit/134c10b9fd49115d118a1deea2ae382ddc555081))


### Bug Fixes

* **ci:** ensure pip is always available ([#88](https://github.com/Avido-AI/avido-py/issues/88)) ([1b5b558](https://github.com/Avido-AI/avido-py/commit/1b5b558de6e54c28afb52d5d1c21c208a2f3876b))
* **ci:** remove publishing patch ([#89](https://github.com/Avido-AI/avido-py/issues/89)) ([d260eb3](https://github.com/Avido-AI/avido-py/commit/d260eb3ce90c994a49857f4d1b1f8e6caf9d4ee4))
* **client:** send all configured auth headers ([#95](https://github.com/Avido-AI/avido-py/issues/95)) ([b089939](https://github.com/Avido-AI/avido-py/commit/b0899397b2cca27253a056da528757b1ba5fcdc7))
* **types:** handle more discriminated union shapes ([#87](https://github.com/Avido-AI/avido-py/issues/87)) ([ee18be8](https://github.com/Avido-AI/avido-py/commit/ee18be8c556c86092e7fcd57ff56690f2f72ce15))


### Chores

* Auto updates from Stainless ([#100](https://github.com/Avido-AI/avido-py/issues/100)) ([5e8e825](https://github.com/Avido-AI/avido-py/commit/5e8e825d16eec5576bf8a1717653379f39d6e247))
* Auto updates from Stainless ([#92](https://github.com/Avido-AI/avido-py/issues/92)) ([19b306d](https://github.com/Avido-AI/avido-py/commit/19b306d91dc95e0b8f459ba45d92fa1a84d0609f))
* Auto updates from Stainless ([#93](https://github.com/Avido-AI/avido-py/issues/93)) ([38e0b74](https://github.com/Avido-AI/avido-py/commit/38e0b7481ed210df7dca09ca7b04428bcc0aa169))
* **internal:** codegen related update ([#85](https://github.com/Avido-AI/avido-py/issues/85)) ([f985244](https://github.com/Avido-AI/avido-py/commit/f985244b0c502acb6a87b7ec9096334ca5cafd88))
* **internal:** codegen related update ([#86](https://github.com/Avido-AI/avido-py/issues/86)) ([9a52b92](https://github.com/Avido-AI/avido-py/commit/9a52b92bf602e6763af3d26dfb343ba66950c42c))
* **internal:** codegen related update ([#96](https://github.com/Avido-AI/avido-py/issues/96)) ([3745f43](https://github.com/Avido-AI/avido-py/commit/3745f430af9f1364d7ec336f727a1664c529b63d))
* **internal:** codegen related update ([#97](https://github.com/Avido-AI/avido-py/issues/97)) ([c2a72ed](https://github.com/Avido-AI/avido-py/commit/c2a72ed2cc87950cdc1aea2f7d9773501c8e1fc5))
* **internal:** remove extra empty newlines ([#83](https://github.com/Avido-AI/avido-py/issues/83)) ([0785de6](https://github.com/Avido-AI/avido-py/commit/0785de64fc4d84760ce2dff8f0dc24ed54976bc1))
* **internal:** remove trailing character ([#94](https://github.com/Avido-AI/avido-py/issues/94)) ([f41d870](https://github.com/Avido-AI/avido-py/commit/f41d870550441a3f4be08f5f8e071b275f5bc0fd))
* **internal:** slight transform perf improvement ([#98](https://github.com/Avido-AI/avido-py/issues/98)) ([dd5eb35](https://github.com/Avido-AI/avido-py/commit/dd5eb35be9f189fc88b582bc6e15a62e89f4ee26))
* **tests:** improve enum examples ([#99](https://github.com/Avido-AI/avido-py/issues/99)) ([0fc7ed9](https://github.com/Avido-AI/avido-py/commit/0fc7ed93e39af0eaa6fbff82ddf0f67396595d4e))

## 1.8.0 (2025-03-12)

Full Changelog: [v1.7.0...v1.8.0](https://github.com/Avido-AI/avido-py/compare/v1.7.0...v1.8.0)

### Features

* **api:** manual updates ([#81](https://github.com/Avido-AI/avido-py/issues/81)) ([43e48ed](https://github.com/Avido-AI/avido-py/commit/43e48ede5f9187eedf4877473c2163fcea853d23))


### Chores

* Auto updates from Stainless ([#79](https://github.com/Avido-AI/avido-py/issues/79)) ([578c736](https://github.com/Avido-AI/avido-py/commit/578c7368871babb40340c8f99700212904a4c1d7))

## 1.7.0 (2025-03-11)

Full Changelog: [v1.6.0...v1.7.0](https://github.com/Avido-AI/avido-py/compare/v1.6.0...v1.7.0)

### Features

* **api:** manual updates ([#76](https://github.com/Avido-AI/avido-py/issues/76)) ([3eec582](https://github.com/Avido-AI/avido-py/commit/3eec582307c14252ae170274077d507780d7ce50))


### Chores

* Auto updates from Stainless ([#77](https://github.com/Avido-AI/avido-py/issues/77)) ([dc90586](https://github.com/Avido-AI/avido-py/commit/dc90586ba1e759db55c19ab24208cfa522543464))

## 1.6.0 (2025-03-04)

Full Changelog: [v1.5.1...v1.6.0](https://github.com/Avido-AI/avido-py/compare/v1.5.1...v1.6.0)

### Features

* **client:** allow passing `NotGiven` for body ([#67](https://github.com/Avido-AI/avido-py/issues/67)) ([dbff040](https://github.com/Avido-AI/avido-py/commit/dbff040aab650794b2b187f54aab6a7eed330c1f))
* **client:** send `X-Stainless-Read-Timeout` header ([#61](https://github.com/Avido-AI/avido-py/issues/61)) ([f3d5ada](https://github.com/Avido-AI/avido-py/commit/f3d5adaa193bbdd6bb46e503b6766c8098032063))


### Bug Fixes

* asyncify on non-asyncio runtimes ([#66](https://github.com/Avido-AI/avido-py/issues/66)) ([f06cec7](https://github.com/Avido-AI/avido-py/commit/f06cec7977861737134ca08c1f2ac8ea7f6174ba))
* **client:** mark some request bodies as optional ([dbff040](https://github.com/Avido-AI/avido-py/commit/dbff040aab650794b2b187f54aab6a7eed330c1f))


### Chores

* **docs:** update client docstring ([#71](https://github.com/Avido-AI/avido-py/issues/71)) ([95a18c9](https://github.com/Avido-AI/avido-py/commit/95a18c920783118be874cbe508d74a37a85a7699))
* **internal:** bummp ruff dependency ([#60](https://github.com/Avido-AI/avido-py/issues/60)) ([138796d](https://github.com/Avido-AI/avido-py/commit/138796d10b29fbcb5e9c2fdcedd82e37a730494b))
* **internal:** change default timeout to an int ([#59](https://github.com/Avido-AI/avido-py/issues/59)) ([a064a7e](https://github.com/Avido-AI/avido-py/commit/a064a7edbfa07b104b2f53ecfcdf034003fc0d78))
* **internal:** fix devcontainers setup ([#68](https://github.com/Avido-AI/avido-py/issues/68)) ([dc46c93](https://github.com/Avido-AI/avido-py/commit/dc46c9399295be7459af1171044e697690e4400e))
* **internal:** fix type traversing dictionary params ([#62](https://github.com/Avido-AI/avido-py/issues/62)) ([a0ce66b](https://github.com/Avido-AI/avido-py/commit/a0ce66bc6c2884d7cd567c1b41aa4fb47f592b95))
* **internal:** minor formatting changes ([#57](https://github.com/Avido-AI/avido-py/issues/57)) ([88270e7](https://github.com/Avido-AI/avido-py/commit/88270e75c1cedde3a2fb3fecff44cf0a7654b770))
* **internal:** minor type handling changes ([#63](https://github.com/Avido-AI/avido-py/issues/63)) ([a8487ba](https://github.com/Avido-AI/avido-py/commit/a8487ba24b4618d28ec6ec8023a71d2626dce071))
* **internal:** properly set __pydantic_private__ ([#69](https://github.com/Avido-AI/avido-py/issues/69)) ([8efa58f](https://github.com/Avido-AI/avido-py/commit/8efa58f03391c71351f2a82c9340dc8b028a3598))
* **internal:** remove unused http client options forwarding ([#72](https://github.com/Avido-AI/avido-py/issues/72)) ([b1bea07](https://github.com/Avido-AI/avido-py/commit/b1bea076374e33c5ec34398ddfc1e3a7c0ccc909))
* **internal:** update client tests ([#65](https://github.com/Avido-AI/avido-py/issues/65)) ([d7b4efe](https://github.com/Avido-AI/avido-py/commit/d7b4efe9c16bcfda57bff6a4f834bb4754e664c3))
* minor change to tests ([#64](https://github.com/Avido-AI/avido-py/issues/64)) ([78bb432](https://github.com/Avido-AI/avido-py/commit/78bb432c55b350c8181f2de23c4c8c9141bb84c3))


### Documentation

* update URLs from stainlessapi.com to stainless.com ([#70](https://github.com/Avido-AI/avido-py/issues/70)) ([0dee5e1](https://github.com/Avido-AI/avido-py/commit/0dee5e1df4ac6d13831da1ac4d1e0d1326dfa56a))

## 1.5.1 (2025-01-23)

Full Changelog: [v1.5.0...v1.5.1](https://github.com/Avido-AI/avido-py/compare/v1.5.0...v1.5.1)

### Chores

* Auto updates from Stainless ([#55](https://github.com/Avido-AI/avido-py/issues/55)) ([fdba936](https://github.com/Avido-AI/avido-py/commit/fdba936ca349e8b910f48582601321475f817ba9))
* **internal:** codegen related update ([#51](https://github.com/Avido-AI/avido-py/issues/51)) ([1593c1f](https://github.com/Avido-AI/avido-py/commit/1593c1f362d69fc720212f2fbecfb2bf53782094))
* **internal:** codegen related update ([#53](https://github.com/Avido-AI/avido-py/issues/53)) ([d1d7801](https://github.com/Avido-AI/avido-py/commit/d1d7801b3170ad251b8429e2ff97ce62e294a36a))
* **internal:** minor style changes ([#54](https://github.com/Avido-AI/avido-py/issues/54)) ([c46fc08](https://github.com/Avido-AI/avido-py/commit/c46fc0866d3ff856dc0c86e9bcafcf4bc09757df))

## 1.5.0 (2025-01-16)

Full Changelog: [v1.4.0...v1.5.0](https://github.com/Avido-AI/avido-py/compare/v1.4.0...v1.5.0)

### Features

* **api:** manual updates ([#47](https://github.com/Avido-AI/avido-py/issues/47)) ([6548383](https://github.com/Avido-AI/avido-py/commit/6548383eacc022ffc24490bafec2d78af35aa7b6))
* **api:** manual updates ([#49](https://github.com/Avido-AI/avido-py/issues/49)) ([5f9f703](https://github.com/Avido-AI/avido-py/commit/5f9f7039988e33fa4c901b4f8976e087238564dd))


### Chores

* Auto updates from Stainless ([#45](https://github.com/Avido-AI/avido-py/issues/45)) ([a259a55](https://github.com/Avido-AI/avido-py/commit/a259a55f5e603b8665f0673131f621b96dbfbb8d))
* Auto updates from Stainless ([#48](https://github.com/Avido-AI/avido-py/issues/48)) ([3948dab](https://github.com/Avido-AI/avido-py/commit/3948dabd04d2b221f2304032f3622a05c27a4066))

## 1.4.0 (2025-01-15)

Full Changelog: [v1.3.2...v1.4.0](https://github.com/Avido-AI/avido-py/compare/v1.3.2...v1.4.0)

### Features

* **api:** manual updates ([#42](https://github.com/Avido-AI/avido-py/issues/42)) ([773476a](https://github.com/Avido-AI/avido-py/commit/773476abd23f2e1f0b050390ec8ba1e85f8f83c4))

## 1.3.2 (2025-01-14)

Full Changelog: [v1.3.1...v1.3.2](https://github.com/Avido-AI/avido-py/compare/v1.3.1...v1.3.2)

### Chores

* Auto updates from Stainless ([#39](https://github.com/Avido-AI/avido-py/issues/39)) ([9e6c6d3](https://github.com/Avido-AI/avido-py/commit/9e6c6d3bd3c2cfe20535b9a219ec46666be00e92))

## 1.3.1 (2025-01-13)

Full Changelog: [v1.3.0...v1.3.1](https://github.com/Avido-AI/avido-py/compare/v1.3.0...v1.3.1)

### Chores

* Auto updates from Stainless ([#36](https://github.com/Avido-AI/avido-py/issues/36)) ([d03084d](https://github.com/Avido-AI/avido-py/commit/d03084dbd2a571faf9910d67a5cfa6c72851db01))

## 1.3.0 (2025-01-13)

Full Changelog: [v1.2.1...v1.3.0](https://github.com/Avido-AI/avido-py/compare/v1.2.1...v1.3.0)

### Features

* **api:** manual updates ([#34](https://github.com/Avido-AI/avido-py/issues/34)) ([24c6c02](https://github.com/Avido-AI/avido-py/commit/24c6c028e60f944518d5eb465e0076c124d82944))


### Bug Fixes

* correctly handle deserialising `cls` fields ([#31](https://github.com/Avido-AI/avido-py/issues/31)) ([cf64cb6](https://github.com/Avido-AI/avido-py/commit/cf64cb6b4208c58f5d5eb4fde497ecb88b94c146))


### Chores

* Auto updates from Stainless ([#33](https://github.com/Avido-AI/avido-py/issues/33)) ([3ba6652](https://github.com/Avido-AI/avido-py/commit/3ba665229eebf61bad067d6ae12d47661c4277bc))

## 1.2.1 (2025-01-09)

Full Changelog: [v1.2.0...v1.2.1](https://github.com/Avido-AI/avido-py/compare/v1.2.0...v1.2.1)

### Bug Fixes

* **api:** better support union schemas with common properties ([#29](https://github.com/Avido-AI/avido-py/issues/29)) ([a82b662](https://github.com/Avido-AI/avido-py/commit/a82b6621fe47006d9785f272cec694c969abbc53))


### Chores

* **internal:** codegen related update ([#28](https://github.com/Avido-AI/avido-py/issues/28)) ([d154a7c](https://github.com/Avido-AI/avido-py/commit/d154a7c5e80205982fb5451598d9c617ce156348))


### Documentation

* fix typos ([#26](https://github.com/Avido-AI/avido-py/issues/26)) ([561d54c](https://github.com/Avido-AI/avido-py/commit/561d54cdff97917aaf394ea9431bd063ce8dd3b4))

## 1.2.0 (2025-01-09)

Full Changelog: [v1.1.2...v1.2.0](https://github.com/Avido-AI/avido-py/compare/v1.1.2...v1.2.0)

### Features

* **api:** manual updates ([#20](https://github.com/Avido-AI/avido-py/issues/20)) ([47278ce](https://github.com/Avido-AI/avido-py/commit/47278cee41c08b69fb5e264e57f2274598230b9c))
* **api:** manual updates ([#22](https://github.com/Avido-AI/avido-py/issues/22)) ([a900248](https://github.com/Avido-AI/avido-py/commit/a9002480c138f6dad5e28400c30884abebc0c1c4))
* **api:** manual updates ([#24](https://github.com/Avido-AI/avido-py/issues/24)) ([f9e2a37](https://github.com/Avido-AI/avido-py/commit/f9e2a37037855f0ce8341251a70f0c25f6990f13))


### Chores

* Auto updates from Stainless ([#18](https://github.com/Avido-AI/avido-py/issues/18)) ([11701d6](https://github.com/Avido-AI/avido-py/commit/11701d66996f0c79ea8a4495482716f502263e85))
* Auto updates from Stainless ([#23](https://github.com/Avido-AI/avido-py/issues/23)) ([b07dafb](https://github.com/Avido-AI/avido-py/commit/b07dafb98069279df95a9366718a5e676ac9177d))
* **internal:** version bump ([#21](https://github.com/Avido-AI/avido-py/issues/21)) ([7edecac](https://github.com/Avido-AI/avido-py/commit/7edecac1d660bf41c2239a3b0a1b52b5eb259197))

## 1.1.2 (2025-01-08)

Full Changelog: [v1.1.1...v1.1.2](https://github.com/Avido-AI/avido-py/compare/v1.1.1...v1.1.2)

### Bug Fixes

* **client:** only call .close() when needed ([#16](https://github.com/Avido-AI/avido-py/issues/16)) ([8ac068e](https://github.com/Avido-AI/avido-py/commit/8ac068e5f7f7ba594e490acaea76f70a6f62641c))

## 1.1.1 (2025-01-08)

Full Changelog: [v1.1.0...v1.1.1](https://github.com/Avido-AI/avido-py/compare/v1.1.0...v1.1.1)

### Chores

* add missing isclass check ([#12](https://github.com/Avido-AI/avido-py/issues/12)) ([04e9a0c](https://github.com/Avido-AI/avido-py/commit/04e9a0c380fc9def7bde16e79598e6196e50330b))
* **internal:** codegen related update ([#14](https://github.com/Avido-AI/avido-py/issues/14)) ([be6589a](https://github.com/Avido-AI/avido-py/commit/be6589a08f08db44983e38917aa6a575d722b7df))

## 1.1.0 (2025-01-07)

Full Changelog: [v1.0.0...v1.1.0](https://github.com/Avido-AI/avido-py/compare/v1.0.0...v1.1.0)

### Features

* **api:** manual updates ([#9](https://github.com/Avido-AI/avido-py/issues/9)) ([6cb9ff4](https://github.com/Avido-AI/avido-py/commit/6cb9ff4212a42e7c8226fa1bc44a6148bd932467))

## 1.0.0 (2025-01-06)

Full Changelog: [v0.1.0-alpha.1...v1.0.0](https://github.com/Avido-AI/avido-py/compare/v0.1.0-alpha.1...v1.0.0)

### Chores

* update SDK settings ([#6](https://github.com/Avido-AI/avido-py/issues/6)) ([7514925](https://github.com/Avido-AI/avido-py/commit/7514925d253e9c99cc6f94b054b3a085bc06eed6))

## 0.1.0-alpha.1 (2025-01-06)

Full Changelog: [v0.0.1-alpha.0...v0.1.0-alpha.1](https://github.com/Avido-AI/avido-py/compare/v0.0.1-alpha.0...v0.1.0-alpha.1)

### Features

* **api:** update via SDK Studio ([a8a1a3a](https://github.com/Avido-AI/avido-py/commit/a8a1a3a3ab26f5d33038e4fb32911c7030398e86))
* **api:** update via SDK Studio ([5e6cc7c](https://github.com/Avido-AI/avido-py/commit/5e6cc7cb4ccfb1bcb8f70311969319dcd087daa3))
* **api:** update via SDK Studio ([d59c381](https://github.com/Avido-AI/avido-py/commit/d59c3818a8037ea0f62f5562032fe0130bd614ab))
* **api:** update via SDK Studio ([24d4494](https://github.com/Avido-AI/avido-py/commit/24d44943efc49ae7a8effd5c0ca6ee41e2727234))
* **api:** update via SDK Studio ([fac078e](https://github.com/Avido-AI/avido-py/commit/fac078e32794c9b44e05d127906914e075293d94))
* **api:** update via SDK Studio ([4dd8dc7](https://github.com/Avido-AI/avido-py/commit/4dd8dc7e4eda290498f2e356905dc1573e0645b6))
* **api:** update via SDK Studio ([1601603](https://github.com/Avido-AI/avido-py/commit/16016038e1a8a0da4a07056a63125a7580edf94d))
* **api:** update via SDK Studio ([7893ff8](https://github.com/Avido-AI/avido-py/commit/7893ff86f62b0914e1480f27689060327c1b3c6d))
* **api:** update via SDK Studio ([0fcef05](https://github.com/Avido-AI/avido-py/commit/0fcef05a4471dfa6df21806402a1fe122cd8f0d6))
* **api:** update via SDK Studio ([a66c23c](https://github.com/Avido-AI/avido-py/commit/a66c23c7c508ebdc0110ac4fe274807d0ee2b093))
* **api:** update via SDK Studio ([dc17892](https://github.com/Avido-AI/avido-py/commit/dc178922d71b2501ef4c18ea56ce715a3d959dc5))


### Chores

* go live ([#1](https://github.com/Avido-AI/avido-py/issues/1)) ([b92b753](https://github.com/Avido-AI/avido-py/commit/b92b753e80237da9b48b76af67ee57cb1da2ecce))
* go live ([#4](https://github.com/Avido-AI/avido-py/issues/4)) ([2a7def0](https://github.com/Avido-AI/avido-py/commit/2a7def013625d8ea2b7051c9330865bb168bd9d9))
* update SDK settings ([#3](https://github.com/Avido-AI/avido-py/issues/3)) ([7cebf61](https://github.com/Avido-AI/avido-py/commit/7cebf61017cfb04a8a5b3c905c205986902ccc58))
